package com.gxlu.ps.netcruise.md;

import com.gxlu.ps.netcruise.md.util.ExProperties;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.Calendar;
import org.apache.log4j.Logger;

/* loaded from: com_gxlu_ps_netcruise_md.jar:com/gxlu/ps/netcruise/md/Configer.class */
public class Configer {
    private static Configer instance = null;
    protected ExProperties config;
    private String fileName;
    protected Logger logger;

    private Configer(String fileName) throws IOException {
        this.config = null;
        this.fileName = null;
        this.logger = null;
        this.config = new ExProperties();
        this.config.load(fileName);
        this.fileName = fileName;
        this.logger = GlobalInstance.getInstance().getLogger();
    }

    public static synchronized Configer getInstance(String fileName) {
        if (instance == null) {
            try {
                instance = new Configer(fileName);
            } catch (IOException e) {
                return (Configer) null;
            }
        }
        return instance;
    }

    public String getPasswdFilePath() {
        return this.config.getProperty("MDSystem", "passwd_file", (String) null);
    }

    public String getAlarmFilePath() {
        return this.config.getProperty("MDSystem", "alarm_file", (String) null);
    }

    public String getCmdFilePath() {
        return this.config.getProperty("MDSystem", "command_file", (String) null);
    }

    public String getErrFilePath() {
        return this.config.getProperty("MDSystem", "error_description_file", (String) null);
    }

    public int getTimeOut() {
        try {
            int time = Integer.parseInt(this.config.getProperty("MDSystem", "time_out", Integer.toString(10)));
            int var2 = time > 0 ? time : 0;
            return var2;
        } catch (NumberFormatException e) {
            return 0;
        }
    }

    public int getTelnetCmdWaitTime() {
        try {
            int time = Integer.parseInt(this.config.getProperty("MDSystem", "telnet_time_out", Integer.toString(180)));
            int var2 = time > 0 ? time : 0;
            return var2;
        } catch (NumberFormatException e) {
            return 0;
        }
    }

    public int getControlPort() {
        try {
            int port = Integer.parseInt(this.config.getProperty("MDSystem", "control_port", Integer.toString(10023)));
            int var2 = (port <= 0 || port >= 65536) ? 0 : port;
            return var2;
        } catch (NumberFormatException e) {
            return 0;
        }
    }

    public int getListenNMSPort() {
        try {
            int port = Integer.parseInt(this.config.getProperty("MDSystem", "listen_NMS_port", Integer.toString(30000)));
            int var2 = (port <= 0 || port >= 65536) ? 0 : port;
            return var2;
        } catch (NumberFormatException e) {
            return 0;
        }
    }

    public int getMaxRetryInterval() {
        try {
            int time = Integer.parseInt(this.config.getProperty("MDSystem", "max_retry_interval", Integer.toString(2)));
            int var2 = time > 0 ? time : 0;
            return var2;
        } catch (NumberFormatException e) {
            return 0;
        }
    }

    public int getTimeCommandInterval() {
        try {
            int var1 = Integer.parseInt(this.config.getProperty("MDSystem", "time_command_interval", Integer.toString(1)));
            return var1;
        } catch (NumberFormatException e) {
            return 0;
        }
    }

    public int getMaxNMSCount() {
        try {
            int count = Integer.parseInt(this.config.getProperty("MDSystem", "max_NMS_count", Integer.toString(5)));
            int var2 = count > 0 ? count : 0;
            return var2;
        } catch (NumberFormatException e) {
            return 0;
        }
    }

    public int getBufferSize() {
        try {
            int size = Integer.parseInt(this.config.getProperty("MDSystem", "alarm_buffer_size", Integer.toString(300)));
            int var2 = size > 0 ? size : 0;
            return var2;
        } catch (NumberFormatException e) {
            return 0;
        }
    }

    public int getSendCacheSize() {
        try {
            int size = Integer.parseInt(this.config.getProperty("MDSystem", "send_cache_size", Integer.toString(1)));
            int var2 = size > 0 ? size : 0;
            return var2;
        } catch (NumberFormatException e) {
            return 0;
        }
    }

    public int getTestSendCacheSize() {
        try {
            int size = Integer.parseInt(this.config.getProperty("MDSystem", "test_send_cache_size", Integer.toString(300)));
            int var2 = size > 0 ? size : 0;
            return var2;
        } catch (NumberFormatException e) {
            return 0;
        }
    }

    public String getRunMode() {
        return this.config.getProperty("MDSystem", "run_mode", "NORMAL");
    }

    public int getAlmChannelType() {
        try {
            int size = Integer.parseInt(this.config.getProperty("MDSystem", "alarm_channel_type", Integer.toString(1)));
            return size;
        } catch (NumberFormatException e) {
            return 1;
        }
    }

    public String getAlmTerminator() {
        return this.config.getProperty("MDSystem", "alarm_terminator", "\r\n");
    }

    public String getNetcoolName() {
        return this.config.getProperty("Netcool", "Netcool_name", (String) null);
    }

    public String getNetcoolAddr() {
        return this.config.getProperty("Netcool", "Netcool_address", (String) null);
    }

    public int getNetcoolPort() {
        try {
            int port = Integer.parseInt(this.config.getProperty("Netcool", "Netcool_port", "0"));
            int var2 = (port <= 0 || port >= 65536) ? 0 : port;
            return var2;
        } catch (NumberFormatException e) {
            return 0;
        }
    }

    public String getTestNetcoolAddr() {
        return this.config.getProperty("Netcool", "test_address", (String) null);
    }

    public int getTestNetcoolPort() {
        try {
            int port = Integer.parseInt(this.config.getProperty("Netcool", "test_port", "0"));
            int var2 = (port <= 0 || port >= 65536) ? 0 : port;
            return var2;
        } catch (NumberFormatException e) {
            return 0;
        }
    }

    public String[] getNMSList() {
        boolean exist = false;
        String[] src = this.config.getSectionList();
        int srcSize = src.length;
        if (2 >= srcSize) {
            return null;
        }
        String[] result = new String[srcSize - 2];
        int j = 0;
        for (int i = 0; i < srcSize; i++) {
            if (!src[i].equals("MDSystem") && !src[i].equals("Netcool")) {
                exist = true;
                result[j] = src[i];
                j++;
            }
        }
        if (exist) {
            return result;
        }
        return null;
    }

    public String getNMSInfo(String nmsName, String nmsProp) {
        String s = this.config.getProperty(nmsName, nmsProp, (String) null);
        if (s == null) {
            return null;
        }
        if (nmsProp.equals("address") && !s.matches("[0-9]{1,3}\\x2e[0-9]{1,3}\\x2e[0-9]{1,3}\\x2e[0-9]{1,3}")) {
            return null;
        }
        if (nmsProp.equals("remote_port") || nmsProp.equals("local_port")) {
            try {
                int i = Integer.parseInt(s);
                if (i <= 0 || i >= 65536) {
                    return (String) null;
                }
            } catch (NumberFormatException e) {
                return (String) null;
            }
        }
        return s;
    }

    public String checkRunMode() {
        String mode = instance.getRunMode();
        if (mode.equals("TEST") && (instance.getTestNetcoolAddr() == null || instance.getTestNetcoolPort() <= 0 || instance.getTestSendCacheSize() <= 0)) {
            return "NORMAL";
        }
        return mode;
    }

    public String getNMSSyncTime(String nmsName) {
        String varPatch = getAlarmFilePath();
        String fName = varPatch.substring(0, varPatch.lastIndexOf("/") + 1).concat(nmsName).concat("LastAlarmTime.var");
        if (fName == null) {
            return null;
        }
        File f = new File(fName);
        if (!f.exists()) {
            return null;
        }
        try {
            BufferedReader br = new BufferedReader(new FileReader(f));
            try {
                String var5 = br.readLine();
                return var5;
            } catch (IOException e) {
                return (String) null;
            }
        } catch (FileNotFoundException e2) {
            return (String) null;
        }
    }

    public void setNMSSyncTimeAndSave(String nmsName, String time) {
        String varPatch = getAlarmFilePath();
        String fName = varPatch.substring(0, varPatch.lastIndexOf("/") + 1).concat(nmsName).concat("LastAlarmTime.var");
        FileWriter fw = null;
        try {
            try {
                File f = new File(fName);
                f.createNewFile();
                fw = new FileWriter(f, false);
                BufferedWriter bw = new BufferedWriter(fw);
                if (time == null) {
                    bw.write("");
                } else {
                    bw.write(time);
                }
                bw.flush();
                this.logger.error(String.valueOf(String.valueOf(fName)).concat(" saved."));
                if (fw != null) {
                    try {
                        fw.close();
                    } catch (IOException e) {
                    }
                }
            } catch (IOException e2) {
                tmpSaveNMSSyncTime(fName, time);
                if (fw != null) {
                    try {
                        fw.close();
                    } catch (IOException e3) {
                    }
                }
            }
        } catch (Throwable th) {
            if (fw != null) {
                try {
                    fw.close();
                } catch (IOException e4) {
                    throw th;
                }
            }
            throw th;
        }
    }

    protected void tmpSaveNMSSyncTime(String fName, String time) {
        FileWriter fw = null;
        Calendar cald = Calendar.getInstance();
        String year = Integer.toString(cald.get(1));
        String month = Integer.toString(cald.get(2) + 1);
        String day = Integer.toString(cald.get(5));
        String hour = Integer.toString(cald.get(11));
        String minute = Integer.toString(cald.get(12));
        String second = Integer.toString(cald.get(13));
        String fName2 = String.valueOf(String.valueOf(new StringBuffer(String.valueOf(String.valueOf(fName))).append(".").append(year).append("-").append(month).append("-").append(day).append("-").append(hour).append("-").append(minute).append("-").append(second)));
        System.out.println(String.valueOf(String.valueOf(new StringBuffer("Can't open time file. SyncTime will save to ").append(this.fileName).append(" ."))));
        try {
            try {
                File f = new File(fName2);
                f.createNewFile();
                fw = new FileWriter(f, false);
                BufferedWriter bw = new BufferedWriter(fw);
                bw.write(time);
                bw.flush();
                if (fw != null) {
                    try {
                        fw.close();
                    } catch (IOException e) {
                    }
                }
            } catch (IOException e2) {
                System.out.println(String.valueOf(String.valueOf(new StringBuffer("Sorry, ").append(fName2).append(" can't open too. SyncTime will lost!!!"))));
                if (fw != null) {
                    try {
                        fw.close();
                    } catch (IOException e3) {
                    }
                }
            }
        } catch (Throwable th) {
            if (fw != null) {
                try {
                    fw.close();
                } catch (IOException e4) {
                    throw th;
                }
            }
            throw th;
        }
    }

    public void saveToFile() {
        this.config.save(this.fileName);
    }

    public String getAlarmLogPath() {
        return this.config.getProperty("MDSystem", "alarm_log_path", (String) null);
    }
}
